@@ -1,14 +1,14 @@
 #define QT_FEATURE_assistant 1
 
-#define QT_FEATURE_clang -1
+#define QT_FEATURE_clang 1
 
-#define QT_FEATURE_clang_rtti -1
+#define QT_FEATURE_clang_rtti 1
 
-#define QT_FEATURE_qdoc -1
+#define QT_FEATURE_qdoc 1
 
-#define QT_FEATURE_clangcpp -1
+#define QT_FEATURE_clangcpp 1
 
-#define QT_FEATURE_designer -1
+#define QT_FEATURE_designer 1
 
 #define QT_FEATURE_distancefieldgenerator -1
 
@@ -22,7 +22,7 @@
 
 #define QT_FEATURE_qev 1
 
-#define QT_FEATURE_qtattributionsscanner -1
+#define QT_FEATURE_qtattributionsscanner 1
 
 #define QT_FEATURE_qtdiag -1
 
